@@ -61,6 +61,7 @@ defines = {
         electric_pole = 1,
         inserter = 1,
         lamp = 1,
+        linked_container = 1,
         offshore_pump = 1,
         programmable_speaker = 1,
         pump = 1,
@@ -215,180 +216,182 @@ defines = {
     entity_status = {
         cant_divide_segments = 10,
         charging = 6,
-        closed_by_circuit_network = 39,
-        disabled = 42,
-        disabled_by_control_behavior = 38,
-        disabled_by_script = 41,
+        closed_by_circuit_network = 40,
+        disabled = 43,
+        disabled_by_control_behavior = 39,
+        disabled_by_script = 42,
         discharging = 7,
         fluid_ingredient_shortage = 20,
         full_output = 22,
         fully_charged = 8,
         item_ingredient_shortage = 21,
-        launching_rocket = 29,
+        launching_rocket = 30,
         low_input_fluid = 18,
         low_power = 12,
-        low_temperature = 35,
-        marked_for_deconstruction = 43,
-        missing_required_fluid = 23,
-        missing_science_packs = 24,
+        low_temperature = 36,
+        marked_for_deconstruction = 44,
+        missing_required_fluid = 24,
+        missing_science_packs = 25,
         networks_connected = 4,
         networks_disconnected = 5,
-        no_ammo = 34,
-        no_fuel = 36,
+        no_ammo = 35,
+        no_fuel = 37,
         no_ingredients = 14,
         no_input_fluid = 19,
         no_minable_resources = 17,
-        no_modules_to_transmit = 30,
-        no_power = 37,
+        no_modules_to_transmit = 31,
+        no_power = 38,
         no_recipe = 15,
         no_research_in_progress = 16,
         normal = 2,
         not_connected_to_rail = 11,
         not_plugged_in_electric_network = 3,
-        opened_by_circuit_network = 40,
+        opened_by_circuit_network = 41,
         out_of_logistic_network = 13,
-        preparing_rocket_for_launch = 27,
-        recharging_after_power_outage = 31,
+        preparing_rocket_for_launch = 28,
+        recharging_after_power_outage = 32,
         turned_off_during_daytime = 9,
-        waiting_for_source_items = 25,
-        waiting_for_space_in_destination = 26,
-        waiting_for_target_to_be_built = 32,
-        waiting_for_train = 33,
-        waiting_to_launch_rocket = 28,
+        waiting_for_source_items = 26,
+        waiting_for_space_in_destination = 27,
+        waiting_for_target_to_be_built = 33,
+        waiting_for_train = 34,
+        waiting_to_launch_rocket = 29,
         working = 1
     },
     events = {
-        on_ai_command_completed = 118,
-        on_area_cloned = 123,
+        on_ai_command_completed = 119,
+        on_area_cloned = 124,
         on_biter_base_built = 57,
-        on_brush_cloned = 124,
-        on_build_base_arrived = 141,
+        on_brush_cloned = 125,
+        on_build_base_arrived = 142,
         on_built_entity = 6,
         on_cancelled_deconstruction = 23,
-        on_cancelled_upgrade = 120,
+        on_cancelled_upgrade = 121,
         on_character_corpse_expired = 94,
-        on_chart_tag_added = 143,
-        on_chart_tag_modified = 144,
-        on_chart_tag_removed = 145,
-        on_chunk_charted = 102,
-        on_chunk_deleted = 111,
+        on_chart_tag_added = 144,
+        on_chart_tag_modified = 145,
+        on_chart_tag_removed = 146,
+        on_chunk_charted = 103,
+        on_chunk_deleted = 112,
         on_chunk_generated = 12,
         on_combat_robot_expired = 83,
         on_console_chat = 73,
         on_console_command = 74,
-        on_cutscene_cancelled = 167,
+        on_cutscene_cancelled = 168,
         on_cutscene_waypoint_reached = 35,
         on_difficulty_settings_changed = 62,
-        on_entity_cloned = 122,
-        on_entity_damaged = 101,
-        on_entity_destroyed = 158,
+        on_entity_cloned = 123,
+        on_entity_damaged = 102,
+        on_entity_destroyed = 159,
         on_entity_died = 4,
-        on_entity_logistic_slot_changed = 171,
+        on_entity_logistic_slot_changed = 172,
         on_entity_renamed = 59,
         on_entity_settings_pasted = 33,
-        on_entity_spawned = 135,
-        on_equipment_inserted = 172,
-        on_equipment_removed = 173,
-        on_force_cease_fire_changed = 151,
+        on_entity_spawned = 136,
+        on_equipment_inserted = 173,
+        on_equipment_removed = 174,
+        on_force_cease_fire_changed = 152,
         on_force_created = 29,
-        on_force_friends_changed = 150,
-        on_force_reset = 104,
-        on_forces_merged = 106,
+        on_force_friends_changed = 151,
+        on_force_reset = 105,
+        on_forces_merged = 107,
         on_forces_merging = 30,
-        on_game_created_from_scenario = 125,
+        on_game_created_from_scenario = 126,
         on_gui_checked_state_changed = 3,
         on_gui_click = 1,
         on_gui_closed = 88,
-        on_gui_confirmed = 146,
+        on_gui_confirmed = 147,
         on_gui_elem_changed = 69,
-        on_gui_location_changed = 147,
+        on_gui_location_changed = 148,
         on_gui_opened = 87,
-        on_gui_selected_tab_changed = 148,
+        on_gui_selected_tab_changed = 149,
         on_gui_selection_state_changed = 60,
-        on_gui_switch_state_changed = 149,
+        on_gui_switch_state_changed = 150,
         on_gui_text_changed = 2,
         on_gui_value_changed = 89,
-        on_land_mine_armed = 105,
+        on_land_mine_armed = 106,
         on_lua_shortcut = 36,
         on_marked_for_deconstruction = 22,
-        on_marked_for_upgrade = 119,
+        on_marked_for_upgrade = 120,
         on_market_item_purchased = 55,
         on_mod_item_opened = 86,
-        on_permission_group_added = 166,
-        on_permission_group_deleted = 165,
-        on_permission_group_edited = 161,
-        on_permission_string_imported = 163,
+        on_permission_group_added = 167,
+        on_permission_group_deleted = 166,
+        on_permission_group_edited = 162,
+        on_permission_string_imported = 164,
         on_picked_up_item = 5,
+        on_player_alt_reverse_selected_area = 176,
         on_player_alt_selected_area = 52,
         on_player_ammo_inventory_changed = 38,
         on_player_armor_inventory_changed = 37,
-        on_player_banned = 113,
+        on_player_banned = 114,
         on_player_built_tile = 47,
-        on_player_cancelled_crafting = 100,
+        on_player_cancelled_crafting = 101,
         on_player_changed_force = 58,
         on_player_changed_position = 85,
         on_player_changed_surface = 53,
         on_player_cheat_mode_disabled = 93,
         on_player_cheat_mode_enabled = 92,
-        on_player_clicked_gps_tag = 159,
+        on_player_clicked_gps_tag = 160,
         on_player_configured_blueprint = 72,
-        on_player_configured_spider_remote = 168,
+        on_player_configured_spider_remote = 169,
         on_player_crafted_item = 13,
         on_player_created = 26,
         on_player_cursor_stack_changed = 31,
         on_player_deconstructed_area = 71,
         on_player_demoted = 78,
         on_player_died = 43,
-        on_player_display_resolution_changed = 97,
-        on_player_display_scale_changed = 98,
+        on_player_display_resolution_changed = 98,
+        on_player_display_scale_changed = 99,
         on_player_driving_changed_state = 28,
         on_player_dropped_item = 56,
-        on_player_fast_transferred = 130,
-        on_player_flushed_fluid = 160,
+        on_player_fast_transferred = 131,
+        on_player_flushed_fluid = 161,
         on_player_gun_inventory_changed = 39,
         on_player_joined_game = 45,
-        on_player_kicked = 114,
+        on_player_kicked = 115,
         on_player_left_game = 46,
         on_player_main_inventory_changed = 34,
         on_player_mined_entity = 67,
         on_player_mined_item = 8,
         on_player_mined_tile = 48,
         on_player_muted = 90,
-        on_player_pipette = 96,
+        on_player_pipette = 97,
         on_player_placed_equipment = 40,
         on_player_promoted = 77,
         on_player_removed = 75,
         on_player_removed_equipment = 41,
-        on_player_repaired_entity = 129,
+        on_player_repaired_entity = 130,
         on_player_respawned = 44,
-        on_player_reverse_selected_area = 174,
+        on_player_reverse_selected_area = 175,
         on_player_rotated_entity = 21,
         on_player_selected_area = 51,
-        on_player_set_quick_bar_slot = 154,
+        on_player_set_quick_bar_slot = 155,
         on_player_setup_blueprint = 70,
-        on_player_toggled_alt_mode = 128,
-        on_player_toggled_map_editor = 121,
-        on_player_trash_inventory_changed = 107,
-        on_player_unbanned = 115,
+        on_player_toggled_alt_mode = 129,
+        on_player_toggled_map_editor = 122,
+        on_player_trash_inventory_changed = 108,
+        on_player_unbanned = 116,
         on_player_unmuted = 91,
         on_player_used_capsule = 76,
-        on_player_used_spider_remote = 169,
-        on_post_entity_died = 134,
+        on_player_used_spider_remote = 170,
+        on_post_entity_died = 135,
         on_pre_build = 9,
-        on_pre_chunk_deleted = 131,
+        on_pre_chunk_deleted = 132,
         on_pre_entity_settings_pasted = 32,
         on_pre_ghost_deconstructed = 95,
-        on_pre_permission_group_deleted = 164,
-        on_pre_permission_string_imported = 162,
-        on_pre_player_crafted_item = 99,
+        on_pre_ghost_upgraded = 96,
+        on_pre_permission_group_deleted = 165,
+        on_pre_permission_string_imported = 163,
+        on_pre_player_crafted_item = 100,
         on_pre_player_died = 42,
-        on_pre_player_left_game = 108,
+        on_pre_player_left_game = 109,
         on_pre_player_mined_item = 11,
-        on_pre_player_removed = 136,
-        on_pre_player_toggled_map_editor = 155,
-        on_pre_robot_exploded_cliff = 132,
-        on_pre_script_inventory_resized = 156,
-        on_pre_surface_cleared = 110,
+        on_pre_player_removed = 137,
+        on_pre_player_toggled_map_editor = 156,
+        on_pre_robot_exploded_cliff = 133,
+        on_pre_script_inventory_resized = 157,
+        on_pre_surface_cleared = 111,
         on_pre_surface_deleted = 65,
         on_research_cancelled = 20,
         on_research_finished = 18,
@@ -397,37 +400,37 @@ defines = {
         on_resource_depleted = 27,
         on_robot_built_entity = 14,
         on_robot_built_tile = 49,
-        on_robot_exploded_cliff = 133,
+        on_robot_exploded_cliff = 134,
         on_robot_mined = 16,
         on_robot_mined_entity = 66,
         on_robot_mined_tile = 50,
         on_robot_pre_mined = 15,
-        on_rocket_launch_ordered = 116,
+        on_rocket_launch_ordered = 117,
         on_rocket_launched = 10,
         on_runtime_mod_setting_changed = 61,
-        on_script_inventory_resized = 157,
-        on_script_path_request_finished = 117,
-        on_script_trigger_effect = 153,
+        on_script_inventory_resized = 158,
+        on_script_path_request_finished = 118,
+        on_script_trigger_effect = 154,
         on_sector_scanned = 7,
         on_selected_entity_changed = 54,
-        on_spider_command_completed = 170,
-        on_string_translated = 152,
-        on_surface_cleared = 109,
+        on_spider_command_completed = 171,
+        on_string_translated = 153,
+        on_surface_cleared = 110,
         on_surface_created = 63,
         on_surface_deleted = 64,
-        on_surface_imported = 126,
-        on_surface_renamed = 127,
-        on_technology_effects_reset = 103,
+        on_surface_imported = 127,
+        on_surface_renamed = 128,
+        on_technology_effects_reset = 104,
         on_tick = 0,
         on_train_changed_state = 25,
         on_train_created = 68,
-        on_train_schedule_changed = 112,
+        on_train_schedule_changed = 113,
         on_trigger_created_entity = 24,
-        on_trigger_fired_artillery = 142,
-        on_unit_added_to_group = 138,
-        on_unit_group_created = 137,
-        on_unit_group_finished_gathering = 140,
-        on_unit_removed_from_group = 139,
+        on_trigger_fired_artillery = 143,
+        on_unit_added_to_group = 139,
+        on_unit_group_created = 138,
+        on_unit_group_finished_gathering = 141,
+        on_unit_removed_from_group = 140,
         on_worker_robot_expired = 84,
         script_raised_built = 79,
         script_raised_destroy = 80,
@@ -469,6 +472,7 @@ defines = {
         player_management = 18,
         production = 4,
         research = 2,
+        script_inventory = 23,
         server_management = 17,
         tile = 19,
         trains = 7,
@@ -478,9 +482,10 @@ defines = {
         activate_copy = 45,
         activate_cut = 46,
         activate_paste = 47,
-        add_permission_group = 226,
+        add_permission_group = 227,
         add_train_station = 96,
-        admin_action = 194,
+        admin_action = 195,
+        alt_reverse_select_area = 164,
         alt_select_area = 162,
         alt_select_blueprint_entities = 121,
         alternative_copy = 119,
@@ -497,14 +502,14 @@ defines = {
         change_active_character_tab = 100,
         change_active_item_group_for_crafting = 98,
         change_active_item_group_for_filters = 99,
-        change_active_quick_bar = 230,
+        change_active_quick_bar = 231,
         change_arithmetic_combinator_parameters = 146,
         change_decider_combinator_parameters = 147,
         change_entity_label = 158,
         change_item_description = 157,
         change_item_label = 156,
-        change_multiplayer_config = 193,
-        change_picking_state = 198,
+        change_multiplayer_config = 194,
+        change_picking_state = 199,
         change_programmable_speaker_alert_parameters = 149,
         change_programmable_speaker_circuit_parameters = 150,
         change_programmable_speaker_parameters = 148,
@@ -528,29 +533,29 @@ defines = {
         deconstruct = 116,
         delete_blueprint_library = 43,
         delete_blueprint_record = 129,
-        delete_custom_tag = 224,
-        delete_permission_group = 225,
+        delete_custom_tag = 225,
+        delete_permission_group = 226,
         destroy_item = 67,
         destroy_opened_item = 22,
         disconnect_rolling_stock = 10,
-        drag_train_schedule = 179,
-        drag_train_wait_condition = 180,
+        drag_train_schedule = 180,
+        drag_train_wait_condition = 181,
         drop_blueprint_record = 128,
         drop_item = 59,
         edit_blueprint_tool_preview = 137,
-        edit_custom_tag = 171,
-        edit_permission_group = 172,
+        edit_custom_tag = 172,
+        edit_permission_group = 173,
         export_blueprint = 139,
-        fast_entity_split = 214,
-        fast_entity_transfer = 212,
+        fast_entity_split = 215,
+        fast_entity_transfer = 213,
         flush_opened_entity_fluid = 54,
-        flush_opened_entity_specific_fluid = 197,
-        go_to_train_station = 239,
+        flush_opened_entity_specific_fluid = 198,
+        go_to_train_station = 240,
         grab_blueprint_record = 127,
         gui_checked_state_changed = 102,
         gui_click = 92,
         gui_confirmed = 93,
-        gui_elem_changed = 177,
+        gui_elem_changed = 178,
         gui_location_changed = 107,
         gui_selected_tab_changed = 104,
         gui_selection_state_changed = 103,
@@ -558,16 +563,16 @@ defines = {
         gui_text_changed = 101,
         gui_value_changed = 105,
         import_blueprint = 140,
-        import_blueprint_string = 173,
+        import_blueprint_string = 174,
         import_blueprints_filtered = 141,
-        import_permissions_string = 174,
+        import_permissions_string = 175,
         inventory_split = 82,
         inventory_transfer = 73,
         launch_rocket = 15,
-        lua_shortcut = 195,
-        map_editor_action = 190,
+        lua_shortcut = 196,
+        map_editor_action = 191,
         market_offer = 95,
-        mod_settings_changed = 169,
+        mod_settings_changed = 170,
         open_achievements_gui = 31,
         open_blueprint_library_gui = 57,
         open_blueprint_record = 126,
@@ -583,61 +588,61 @@ defines = {
         open_production_gui = 16,
         open_technology_gui = 14,
         open_tips_and_tricks_gui = 56,
-        open_train_gui = 220,
-        open_train_station_gui = 237,
+        open_train_gui = 221,
+        open_train_station_gui = 238,
         open_trains_gui = 30,
         paste_entity_settings = 21,
         place_equipment = 108,
-        quick_bar_pick_slot = 187,
-        quick_bar_set_selected_page = 188,
-        quick_bar_set_slot = 186,
+        quick_bar_pick_slot = 188,
+        quick_bar_set_selected_page = 189,
+        quick_bar_set_slot = 187,
         reassign_blueprint = 125,
         remove_cables = 138,
-        remove_train_station = 238,
+        remove_train_station = 239,
         reset_assembling_machine = 13,
         reset_item = 66,
         reverse_select_area = 163,
-        rotate_entity = 213,
+        rotate_entity = 214,
         select_area = 161,
         select_blueprint_entities = 120,
-        select_entity_slot = 182,
-        select_item = 181,
-        select_mapper_slot = 184,
+        select_entity_slot = 183,
+        select_item = 182,
+        select_mapper_slot = 185,
         select_next_valid_gun = 41,
-        select_tile_slot = 183,
+        select_tile_slot = 184,
         send_spidertron = 111,
-        set_auto_launch_rocket = 206,
-        set_autosort_inventory = 203,
-        set_behavior_mode = 211,
-        set_car_weapons_control = 228,
+        set_auto_launch_rocket = 207,
+        set_autosort_inventory = 204,
+        set_behavior_mode = 212,
+        set_car_weapons_control = 229,
         set_circuit_condition = 86,
         set_circuit_mode_of_operation = 91,
-        set_controller_logistic_trash_filter_item = 165,
-        set_deconstruction_item_tile_selection_mode = 223,
-        set_deconstruction_item_trees_and_rocks_only = 222,
-        set_entity_color = 221,
-        set_entity_energy_property = 170,
-        set_entity_logistic_trash_filter_item = 166,
+        set_controller_logistic_trash_filter_item = 166,
+        set_deconstruction_item_tile_selection_mode = 224,
+        set_deconstruction_item_trees_and_rocks_only = 223,
+        set_entity_color = 222,
+        set_entity_energy_property = 171,
+        set_entity_logistic_trash_filter_item = 167,
         set_filter = 84,
-        set_flat_controller_gui = 204,
-        set_heat_interface_mode = 236,
-        set_heat_interface_temperature = 235,
-        set_infinity_container_filter_item = 167,
-        set_infinity_container_remove_unfiltered_items = 227,
-        set_infinity_pipe_filter = 168,
-        set_inserter_max_stack_size = 219,
+        set_flat_controller_gui = 205,
+        set_heat_interface_mode = 237,
+        set_heat_interface_temperature = 236,
+        set_infinity_container_filter_item = 168,
+        set_infinity_container_remove_unfiltered_items = 228,
+        set_infinity_pipe_filter = 169,
+        set_inserter_max_stack_size = 220,
         set_inventory_bar = 113,
-        set_linked_container_link_i_d = 245,
+        set_linked_container_link_i_d = 247,
         set_logistic_filter_item = 89,
         set_logistic_filter_signal = 90,
-        set_player_color = 241,
-        set_recipe_notifications = 205,
-        set_request_from_buffers = 229,
-        set_research_finished_stops_game = 218,
+        set_player_color = 243,
+        set_recipe_notifications = 206,
+        set_request_from_buffers = 230,
+        set_research_finished_stops_game = 219,
         set_signal = 87,
-        set_splitter_priority = 233,
-        set_train_stopped = 215,
-        set_trains_limit = 243,
+        set_splitter_priority = 234,
+        set_train_stopped = 216,
+        set_trains_limit = 245,
         set_vehicle_automatic_targeting_parameters = 151,
         setup_assembling_machine = 78,
         setup_blueprint = 122,
@@ -650,10 +655,10 @@ defines = {
         start_research = 88,
         start_walking = 61,
         stop_building_by_moving = 53,
-        switch_connect_to_logistic_network = 210,
-        switch_constant_combinator_state = 207,
-        switch_inserter_filter_mode_state = 209,
-        switch_power_switch_state = 208,
+        switch_connect_to_logistic_network = 211,
+        switch_constant_combinator_state = 208,
+        switch_inserter_filter_mode_state = 210,
+        switch_power_switch_state = 209,
         switch_to_rename_stop_gui = 28,
         take_equipment = 109,
         toggle_deconstruction_item_entity_filter_mode = 38,
@@ -666,7 +671,7 @@ defines = {
         toggle_personal_logistic_requests = 51,
         toggle_personal_roboport = 49,
         toggle_show_entity_info = 24,
-        translate_string = 196,
+        translate_string = 197,
         undo = 48,
         upgrade = 117,
         upgrade_opened_blueprint_by_item = 131,
@@ -676,6 +681,10 @@ defines = {
         wire_dragging = 76,
         write_to_console = 94
     },
+    input_method = {
+        game_controller = 1,
+        keyboard_and_mouse = 0
+    },
     inventory = {
         artillery_turret_ammo = 1,
         artillery_wagon_ammo = 1,
@@ -713,6 +722,9 @@ defines = {
         robot_cargo = 1,
         robot_repair = 2,
         rocket = 1,
+        rocket_silo_input = 2,
+        rocket_silo_modules = 4,
+        rocket_silo_output = 3,
         rocket_silo_result = 6,
         rocket_silo_rocket = 5,
         spider_ammo = 3,
@@ -1103,6 +1115,7 @@ defines = {
         resource_entity_gui = "resource-entity-gui",
         roboport_gui = "roboport-gui",
         rocket_silo_gui = "rocket-silo-gui",
+        script_inventory_gui = "script-inventory-gui",
         server_config_gui = "server-config-gui",
         spider_vehicle_gui = "spider-vehicle-gui",
         splitter_gui = "splitter-gui",
@@ -1139,6 +1152,23 @@ defines = {
             straight = 1
         }
     },
+    rocket_silo_status = {
+        arms_advance = 6,
+        arms_retract = 10,
+        building_rocket = 0,
+        create_rocket = 1,
+        doors_closing = 13,
+        doors_opened = 4,
+        doors_opening = 3,
+        engine_starting = 9,
+        launch_started = 14,
+        launch_starting = 8,
+        lights_blinking_close = 12,
+        lights_blinking_open = 2,
+        rocket_flying = 11,
+        rocket_ready = 7,
+        rocket_rising = 5
+    },
     shooting = {
         not_shooting = 0,
         shooting_enemies = 1,
