@@ -25,6 +25,19 @@ class Beacon(ModulesMixin, RequestItemsMixin, Entity):
     An entity designed to apply module effects to other machine's in it's radius.
     """
 
+    # fmt: off
+    # _exports = {
+    #     **Entity._exports,
+    #     **RequestItemsMixin._exports,
+    #     **ModulesMixin._exports,
+    # }
+    # fmt: on
+
+    _exports = {}
+    _exports.update(Entity._exports)
+    _exports.update(RequestItemsMixin._exports)
+    _exports.update(ModulesMixin._exports)
+
     def __init__(self, name=beacons[0], **kwargs):
         # type: (str, **dict) -> None
         """
