@@ -18,6 +18,19 @@ class Boiler(RequestItemsMixin, DirectionalMixin, Entity):
     fluid (usually steam).
     """
 
+    # fmt: off
+    # _exports = {
+    #     **Entity._exports,
+    #     **DirectionalMixin._exports,
+    #     **RequestItemsMixin._exports,
+    # }
+    # fmt: on
+
+    _exports = {}
+    _exports.update(Entity._exports)
+    _exports.update(DirectionalMixin._exports)
+    _exports.update(RequestItemsMixin._exports)
+
     def __init__(self, name=boilers[0], **kwargs):
         # type: (str, **dict) -> None
         """
