@@ -21,6 +21,21 @@ class Container(InventoryMixin, RequestItemsMixin, CircuitConnectableMixin, Enti
     An entity that holds items.
     """
 
+    # fmt: off
+    # _exports = {
+    #     **Entity._exports,
+    #     **CircuitConnectableMixin._exports,
+    #     **RequestItemsMixin._exports,
+    #     **InventoryMixin._exports,
+    # }
+    # fmt: on
+
+    _exports = {}
+    _exports.update(Entity._exports)
+    _exports.update(CircuitConnectableMixin._exports)
+    _exports.update(RequestItemsMixin._exports)
+    _exports.update(InventoryMixin._exports)
+
     def __init__(self, name=containers[0], **kwargs):
         # type: (str, **dict) -> None
         super(Container, self).__init__(name, containers, **kwargs)
