@@ -18,6 +18,17 @@ class Gate(DirectionalMixin, Entity):
     A wall that opens near the player.
     """
 
+    # fmt: off
+    # _exports = {
+    #     **Entity._exports,
+    #     **DirectionalMixin._exports
+    # }
+    # fmt: on
+
+    _exports = {}
+    _exports.update(Entity._exports)
+    _exports.update(DirectionalMixin._exports)
+
     def __init__(self, name=gates[0], **kwargs):
         # type: (str, **dict) -> None
         super(Gate, self).__init__(name, gates, **kwargs)
