@@ -17,6 +17,15 @@ class HeatPipe(Entity):
     An entity used to transfer thermal energy.
     """
 
+    # fmt: off
+    # _exports = {
+    #     **Entity._exports
+    # }
+    # fmt: on
+
+    _exports = {}
+    _exports.update(Entity._exports)
+
     def __init__(self, name=heat_pipes[0], **kwargs):
         # type: (str, **dict) -> None
         super(HeatPipe, self).__init__(name, heat_pipes, **kwargs)
