@@ -19,6 +19,21 @@ class Loader(FiltersMixin, IOTypeMixin, DirectionalMixin, Entity):
     vise-versa.
     """
 
+    # fmt: off
+    # _exports = {
+    #     **Entity._exports,
+    #     **DirectionalMixin._exports,
+    #     **IOTypeMixin._exports,
+    #     **FiltersMixin._exports,
+    # }
+    # fmt: on
+
+    _exports = {}
+    _exports.update(Entity._exports)
+    _exports.update(DirectionalMixin._exports)
+    _exports.update(IOTypeMixin._exports)
+    _exports.update(FiltersMixin._exports)
+
     def __init__(self, name=loaders[0], **kwargs):
         # type: (str, **dict) -> None
         super(Loader, self).__init__(name, loaders, **kwargs)
