@@ -24,6 +24,21 @@ class LogisticActiveContainer(
     logistic network.
     """
 
+    # fmt: off
+    # _exports = {
+    #     **Entity._exports,
+    #     **CircuitConnectableMixin._exports,
+    #     **RequestItemsMixin._exports,
+    #     **InventoryMixin._exports,
+    # }
+    # fmt: on
+
+    _exports = {}
+    _exports.update(Entity._exports)
+    _exports.update(CircuitConnectableMixin._exports)
+    _exports.update(RequestItemsMixin._exports)
+    _exports.update(InventoryMixin._exports)
+
     def __init__(self, name=logistic_active_containers[0], **kwargs):
         # type: (str, **dict) -> None
         super(LogisticActiveContainer, self).__init__(
