@@ -29,6 +29,23 @@ class LogisticStorageContainer(
     logistic network.
     """
 
+    # fmt: off
+    # _exports = {
+    #     **Entity._exports,
+    #     **RequestFiltersMixin._exports,
+    #     **CircuitConnectableMixin._exports,
+    #     **RequestItemsMixin._exports,
+    #     **InventoryMixin._exports,
+    # }
+    # fmt: on
+
+    _exports = {}
+    _exports.update(Entity._exports)
+    _exports.update(RequestFiltersMixin._exports)
+    _exports.update(CircuitConnectableMixin._exports)
+    _exports.update(RequestItemsMixin._exports)
+    _exports.update(InventoryMixin._exports)
+
     def __init__(self, name=logistic_storage_containers[0], **kwargs):
         # type: (str, **dict) -> None
         super(LogisticStorageContainer, self).__init__(
