@@ -34,8 +34,8 @@ class MiningDrill(
     RequestItemsMixin,
     CircuitReadResourceMixin,
     CircuitConditionMixin,
-    EnableDisableMixin,
     LogisticConditionMixin,
+    EnableDisableMixin,
     ControlBehaviorMixin,
     CircuitConnectableMixin,
     DirectionalMixin,
@@ -45,6 +45,33 @@ class MiningDrill(
     An entity that extracts resources from the environment.
     """
 
+    # fmt: off
+    # _exports = {
+    #     **Entity._exports,
+    #     **DirectionalMixin._exports,
+    #     **CircuitConnectableMixin._exports,
+    #     **ControlBehaviorMixin._exports,
+    #     **EnableDisableMixin._exports,
+    #     **LogisticConditionMixin._exports,
+    #     **CircuitConditionMixin._exports,
+    #     **CircuitReadResourceMixin._exports,
+    #     **RequestItemsMixin._exports,
+    #     **ModulesMixin._exports,
+    # }
+    # fmt: on
+
+    _exports = {}
+    _exports.update(Entity._exports)
+    _exports.update(DirectionalMixin._exports)
+    _exports.update(CircuitConnectableMixin._exports)
+    _exports.update(ControlBehaviorMixin._exports)
+    _exports.update(EnableDisableMixin._exports)
+    _exports.update(LogisticConditionMixin._exports)
+    _exports.update(CircuitConditionMixin._exports)
+    _exports.update(CircuitReadResourceMixin._exports)
+    _exports.update(RequestItemsMixin._exports)
+    _exports.update(ModulesMixin._exports)
+
     def __init__(self, name=mining_drills[0], **kwargs):
         # type: (str, **dict) -> None
         super(MiningDrill, self).__init__(name, mining_drills, **kwargs)
