@@ -17,6 +17,17 @@ class Reactor(RequestItemsMixin, Entity):
     An entity that converts a fuel into thermal energy.
     """
 
+    # fmt: off
+    # _exports = {
+    #     **Entity._exports,
+    #     **RequestItemsMixin._exports
+    # }
+    # fmt: on
+
+    _exports = {}
+    _exports.update(Entity._exports)
+    _exports.update(RequestItemsMixin._exports)
+
     def __init__(self, name=reactors[0], **kwargs):
         # type: (str, **dict) -> None
         super(Reactor, self).__init__(name, reactors, **kwargs)
